@@ -1,12 +1,10 @@
 package ZeroMQ;
 use strict;
 BEGIN {
-    our $VERSION = '0.02_03';
+    our $VERSION = '0.02_04';
     our @ISA = qw(Exporter);
-    require XSLoader;
-    XSLoader::load('ZeroMQ', $VERSION);
 }
-
+use ZeroMQ::Raw ();
 use ZeroMQ::Context;
 use ZeroMQ::Socket;
 use ZeroMQ::Message;
